hepstats.splot package
======================

.. automodule:: hepstats.splot
   :members:
   :undoc-members:
   :show-inheritance:
   :inherited-members:

Submodules
----------

.. toctree::
   :maxdepth: 4

   hepstats.splot.exceptions
   hepstats.splot.sweights
